==> liblxqt_0.14.1.1+rb2.orig.tar.xz: liblxqt-0.14.1.1+rb2/translations/liblxqt_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erro no Gerenciador de Energia do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Falha ao hibernar.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Notificações de Contingência</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Encerrar sessão</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspender sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Deseja realmente suspender o computador?&lt;p&gt;Suspende o computador em um estado de baixa energia. O estado do sistema não é preservado se a energia for perdida.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Deseja realmente hibernar o computador?&lt;p&gt;Hiberna o computador em um estado de baixa energia. O estado do sistema é preservado se a energia for perdida.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Reiniciar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Deseja realmente reiniciar o computador? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Desligar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Deseja realmente desligar o computador? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Encerrar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Deseja realmente encerrar a sessão? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erro no Gerenciador de Energia do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Falha ao hibernar.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Falha ao suspender.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Bloquear tela</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Erro no Protetor de Tela</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="162"/>
        <location filename="../lxqtscreensaver.cpp" line="168"/>
        <location filename="../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Erro na ativação do protetor de tela</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Um erro ocorreu ao iniciar o protetor de tela. Erro desconhecido - valor retornado não documentado de xdg-screensaver: %1.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Ocorreu um erro ao iniciar o protetor de tela. Erro de sintaxe nos argumentos do xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Ocorreu um erro ao iniciar o protetor de tela. Garanta que você tenha o xscreensaver instalado e funcionado.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Ocorreu um erro ao iniciar o protetor de tela. A ação &apos;ativar&apos; falhou. Garanta que você tenha o xscreensaver instalado e funcionado.</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Escolha a página a ser exibida.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Erro no gerenciamento de energia</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface é inválida</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Erro no gerenciamento de energia (chamada D-Bus)</translation>
    </message>
</context>
</TS>

==> liblxqt_0.15.0.orig.tar.xz: liblxqt-0.15.0/translations/liblxqt_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erro no Gerenciador de Energia do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>Hibernate failed.</source>
        <translation>Falha ao hibernar.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Notificações de Contingência</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="118"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="125"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="132"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="139"/>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="146"/>
        <source>Logout</source>
        <translation>Encerrar sessão</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Suspend</source>
        <translation>Suspender sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Deseja realmente suspender o computador?&lt;p&gt;Suspende o computador em um estado de baixa energia. O estado do sistema não é preservado se a energia for perdida.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Deseja realmente hibernar o computador?&lt;p&gt;Hiberna o computador em um estado de baixa energia. O estado do sistema é preservado se a energia for perdida.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Reboot</source>
        <translation>Reiniciar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Deseja realmente reiniciar o computador? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Shutdown</source>
        <translation>Desligar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Deseja realmente desligar o computador? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>LXQt Session Logout</source>
        <translation>Encerrar sessão do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="199"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Deseja realmente encerrar a sessão? Todos os trabalhos não salvos serão perdidos...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>LXQt Power Manager Error</source>
        <translation>Erro no Gerenciador de Energia do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <source>Hibernate failed.</source>
        <translation>Falha ao hibernar.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>Suspend failed.</source>
        <translation>Falha ao suspender.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="161"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Falha ao executar &quot;%1&quot;. Verifique se você possui um bloqueador/protetor de tela compatível com o xdg-screensaver instalado e em execução.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="165"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Falha ao executar &quot;%1&quot;. Verifique se o bloqueador/protetor de tela especificado está instalado e funcionando.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="243"/>
        <source>Lock Screen</source>
        <translation>Bloquear tela</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Erro no Protetor de Tela</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Escolha a página a ser exibida.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Erro no gerenciamento de energia</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface é inválida</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Erro no gerenciamento de energia (chamada D-Bus)</translation>
    </message>
</context>
</TS>
